@@ -194,9 +194,9 @@ def fkt(input_file, tmax=-1.0, tmax_fraction=0.75,
     func = _func_db[func]
     files = [input_file] + list(input_files)
     traj = _get_trajectories(files, global_args)
-    bar = progress(active=True, total=len(files))
+    # bar = progress(active=True, total=len(files))
     for i, th in enumerate(traj):
-        bar.update(i)
+        # bar.update(i)
         if tmax > 0:
             t_grid = [0.0] + func(th.timestep, tmax, tsamples)
         elif tmax_fraction > 0:
@@ -339,7 +339,7 @@ def ba(input_file, dtheta=4.0, grandcanonical=False, *input_files, **global_args
             cf = pp.Filter(cf, global_args['filter'])
         cf.do(update=global_args['update'])
 
-        # ids = distinct_species(th[0].particle)
-        # if len(ids) > 1 and not global_args['no_partial']:
-        #     cf = Partial(pp.BondAngleDistribution, ids, th, dtheta=dtheta, norigins=global_args['norigins'])
-        #     cf.do(update=global_args['update'])
+        ids = distinct_species(th[0].particle)
+        if len(ids) > 1 and not global_args['no_partial']:
+            cf = Partial(pp.BondAngleDistribution, ids, th, dtheta=dtheta, norigins=global_args['norigins'])
+            cf.do(update=global_args['update'])
